@@ -3,7 +3,7 @@ package OpenTracing::Common;
 use strict;
 use warnings;
 
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 =encoding utf8
 
@@ -13,7 +13,7 @@ OpenTracing::Common - provides common logic between OpenTracing classes
 
 =head1 DESCRIPTION
 
-No user-serviceable parts inside.
+No user-serviceable parts inside. Currently just provides a standard constructor.
 
 =cut
 
